<?php
/**
 
 */

//namespace Joomla\Component\Contact\Site\Service;

\defined('_JEXEC') or die;

use Joomla\CMS\Application\SiteApplication;
use Joomla\CMS\Categories\CategoryFactoryInterface;
use Joomla\CMS\Categories\CategoryInterface;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Component\Router\RouterView;
use Joomla\CMS\Component\Router\RouterViewConfiguration;
use Joomla\CMS\Component\Router\Rules\MenuRules;
use Joomla\CMS\Component\Router\Rules\NomenuRules;
use Joomla\CMS\Component\Router\Rules\StandardRules;
use Joomla\CMS\Menu\AbstractMenu;
use Joomla\Database\DatabaseInterface;
use Joomla\Database\ParameterType;
use Joomla\CMS\Factory;

/**
 * Routing class from com_contact
 *
 * @since  3.3
 */
class DebateRouter extends RouterView
{
	/**
	 * Flag to remove IDs
	 *
	 * @var    boolean
	 */
	protected $noIDs = false;

	/**
	 * The category factory
	 *
	 * @var CategoryFactoryInterface
	 *
	 * @since  4.0.0
	 */
	private $categoryFactory;

	/**
	 * The category cache
	 *
	 * @var  array
	 *
	 * @since  4.0.0
	 */
	private $categoryCache = [];

	/**
	 * The db
	 *
	 * @var DatabaseInterface
	 *
	 * @since  4.0.0
	 */
	private $db;
  
    protected static $categoryN = [];
    protected static $categoryP = [];
    protected static $messageN = [];
    protected static $messageP = [];
    protected static $fonderP = [];
    protected static $fonderN= [];

	/**
	 * Content Component router constructor
	 *
	 * @param   SiteApplication           $app              The application object
	 * @param   AbstractMenu              $menu             The menu object to work with
	 * @param   CategoryFactoryInterface  $categoryFactory  The category object
	 * @param   DatabaseInterface         $db               The database object
	 */
	public function __construct($app=null,  $menu=null)
	{
		

		$params = ComponentHelper::getParams('com_debate');
		$this->noIDs = (bool) $params->get('sef_ids');
		
		$categories = new RouterViewConfiguration('categories');
		$categories->setKey('id');
		$this->registerView($categories);
		
		
		$category = new RouterViewConfiguration('category');		
		$category->setKey('id')->setParent($categories, 'catid');	
		$this->registerView($category);
		
		
		$message = new RouterViewConfiguration('message');
		$message->setKey('id')->setName('message')->setParent($category, 'catid');
		$this->registerView($message);	
		
      
      $fonders = new RouterViewConfiguration('fonders');
      $fonders->setKey('id');
      $this->registerView($fonders);
      
		$fonder = new RouterViewConfiguration('fonder');
		$fonder->setKey('id')->setNestable();  
		$this->registerView($fonder);
		
		$deprive = new RouterViewConfiguration('deprive');
		
		$this->registerView($deprive);
		
		parent::__construct($app, $menu);

		$this->attachRule(new MenuRules($this));
		$this->attachRule(new StandardRules($this));
		$this->attachRule(new NomenuRules($this));
	}

	public function getCategorySegment($id, $query)
	{
           

	   $category = DebateRouter::getCategoryById($id);
    
		if (isset($category->id)) {

		   $path = DebateRouter::getThePath(array(), (int)$category->id, $category->parent_id, $category->title, $category->alias);
        
			if ($this->noIDs) {
				foreach ($path as &$segment) {
					list($id, $segment) = explode(':', $segment, 2);
				}
			}

			return $path;
		}

		return array();
      

	}

	
	public function getCategoriesSegment($id, $query)
	{
		return $this->getCategorySegment($id, $query);
		

	}

	
	public function getMessageSegment($id,  $query)
	{
      
       $m = DebateRouter::getMessageById($id);
      if(isset($m->title))
       $path=  DebateRouter::getMessagePath(array(), $id, $m->title);
      	$path[0] = '1:root';
		  $path[$id] = str_replace(" ", "-", $path[$id]);
      if($this->noIDs)
       		return array( 'id'=>$m->id );
      return $path;

	}
	
  
    public function getFondersSegment($id,  $query)
	{
      return $this->getFonderSegment($id, $query);
    }
	
	public function getFonderSegment($id,  $query)
	{
  
	   $m = DebateRouter::getFonderById($id);
	
      
      if(isset($m->name))
       $path=  DebateRouter::getFonderPath(array(), $id, $m->name);
  
     $path[0] = '1:root';
      
       $path[$id] = str_replace(" ", "-", $path[$id]);
	  if ($this->noIDs) {
				foreach ($path as &$segment) {
					list($id, $segment) = explode(':', $segment, 2);
				}
			}
 
      return $path;
      
	
	}
	
	
	public function getDepriveSegment($id,  $query)
	{	
		
						return array('format'=> 'json');

	}

	

	public function getCategoryId($segment, $query)
	{
		return (int) $segment;
	}
  public static function getMessageById($id)
  {
    	$db = Factory::getDBO();
            $query = $db->getQuery('true');
            $query->select('*')->from($db->quoteName('#__debate'))->where('id = '.$db->quote($id));
      $db->setQuery($query);
     
      $r = $db->loadObject();
      self::$messageN[$id]=$r;
      return self::$messageN[$id];
      
  }
    public static function getMessagePath($path = array(), $id = 0,  $title = '')
    {
			$path[$id]	= $id.':'.$title;
    
      self::$messageP[$id] = $path;
		return self::$messageP[$id];
    }
  
   public static function getFonderById($id)
  {
    	$db = Factory::getDBO();
            $query = $db->getQuery('true');
            $query->select('*')->from($db->quoteName('#__debate_fonders'))->where('userid = '.$db->quote($id));
      $db->setQuery($query);
     
      $r = $db->loadObject();
      self::$fonderN[$id]=$r;
      return self::$fonderN[$id];
      
  }
    public static function getFonderPath($path = array(), $id = 0,  $name = '')
    {
    
			$path[$id]	= (int)$id.':'.$name;
     
      self::$fonderP[$id] = $path;
      
		return self::$fonderP[$id];
        
    }
  
  
    public  static function getCategoryById($id)
   {
      
      	$id = (int)$id;
	

			$db = Factory::getDBO();
            $query = $db->getQuery('true');
            $query->select('*')->from($db->quoteName('#__categories'))->where('id = '.$db->quote($id))->where('extension = '.$db->quote('com_debate'));
	
			$db->setQuery( $query );

			$category = $db->loadObject();
        
			if (!empty($category) && isset($category->id) && (int)$category->id > 0) {
 $query = $db->getQuery('true');
    $query->select('*')->from($db->quoteName('#__categories'))->where('parent_id = '.$db->quote($id))->where('extension = '.$db->quote('com_debate'));
			
				$db->setQuery( $query );
				$subcategories = $db->loadObjectList();
            
				if (!empty($subcategories)) {
					$category->subcategories = $subcategories;
				}
			}
            
			self::$categoryN[$id] = $category;
		
		return self::$categoryN[$id];
      
   }
    public static function getThePath($path = array(), $id = 0, $parent_id = 0, $title = '', $alias = '')
    {
			self::$categoryP[$id]	= self::getTreePath($path, $id, $parent_id, $title, $alias);
  
		return self::$categoryP[$id];
    }
     public static function getTreePath($path = array(), $id = 0, $parent_id = 0, $title = '', $alias = '')
     {
       	static $iCT = 0;

		if ((int)$id > 0) {
			
			$path[$id] = (int)$id. ':'. $alias;
		}

		if ((int)$parent_id > 0) {
			$db = Factory::getDBO();
          $query = $db->getQuery('true');
    $query->select('*')->from($db->quoteName('#__categories'))->where('id = '.$db->quote($parent_id))->where('extension = '.$db->quote('com_debate'));
       
			$db->setQuery( $query );
			$category = $db->loadObject();
   

			if (isset($category->id)) {
				$id 	= (int)$category->id;
				$title 	= '';
				if (isset($category->title)) {
					$title = $category->title;
				}

				$alias 	= '';
				if (isset($category->alias)) {
					$alias = $category->alias;
				}

				$parent_id = 0;
				if (isset($category->parent_id)) {
					$parent_id = (int)$category->parent_id;
				}
				$iCT++;

		//	$path = self::getPathTree($path, (int)$id, (int)$parent_id, $title, $alias);
              //$path = $this->getPathTree($path, (int)$id, (int)$parent_id, $title, $alias);
			}
		}
       
		return $path;
     }

	public function getCategoriesId($segment, $query)
	{
		return $this->getCategoryId($segment, $query);
	}
    public function getFondersId($segment, $query)
	{
		return $this->getFonderId($segment, $query);
	}
	
	public function getMessageId($segment, $query)
	{
				return (int) $segment;

	}
	
	
	public function getFonderId($segment, $query)
	{
      	if ($this->noIDs)
		{
			$db = Factory::getDbo();
			$dbquery = $db->getQuery(true);
			$dbquery->select($dbquery->qn('id'))
				->from($dbquery->qn('#__debate_fonders'))
				->where('userid = ' . $dbquery->q($query['id']));
			$db->setQuery($dbquery);

			return (int) $db->loadResult();
		}
  
      
		return (int) $segment;
	}
	
	public function getDepriveId($segment, $query)
	{
		return $segment;
	}
	   public function parse(&$segments){
      
		return parent::parse($segments);
	}

    public function build(&$query) {

		
		if($query['view']==='deprive')
		{
		
			unset($query['Itemid']);
         
		}
     
		return parent::build($query);
	}

}



function DebateBuildRoute(&$query)
{

	$app = Factory::getApplication();
	$router = new DebateRouter($app, $app->getMenu());

  
  
	return $router->build($query);
}


function DebateParseRoute($segments)
{


	$app = Factory::getApplication();
	$router = new DebateRouter($app, $app->getMenu());

	return $router->parse($segments);
}


